---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: ''
assignees: ''

---

## Is your feature request related to a problem? If so, please describe it.
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

## How you envision the solution
A clear and concise description of what you want to happen.

## Describe alternatives you've considered
A clear and concise description of any alternative solutions or features you have considered.

## Additional context
Add any other context or screenshots about the feature request here.
